﻿//
// Copyright (c) 2009-2015, MindFusion LLC - Bulgaria.
//
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using MindFusion.Scheduling.WebForms;
using System.Xml;
using System.IO;
using MindFusion.Scheduling;
using System.Drawing;

namespace MindFusion.Scheduling.Samples.CS.Demo
{
	public partial class _Default : System.Web.UI.Page
	{
		/// <summary>
		/// Handles the Page.Load event and prepares the page with the calendar.
		/// </summary>
		protected void Page_Load(object sender, EventArgs e)
		{
			if (!IsPostBack)
			{
				// Initialize dates to be today
				_calendar.TimetableSettings.Dates.Clear();
				for (int i = 0; i < 5; i++)
				{
					_calendar.TimetableSettings.Dates.Add(new TimetableDate(
						DateTime.Today + new TimeSpan(i * TimeSpan.TicksPerDay)));
				}
				Session.Add("_dates", _calendar.TimetableSettings.Dates);

				_calendar.Date = DateTime.Today;
				_calendar.EndDate = DateTime.Today + TimeSpan.FromDays(60);
				
				InitSettings();

				_calendar.ItemSettings.ItemsVisible = State.Enabled;
				_calendar.ItemSettings.HeaderSize = Unit.Pixel(25);
				_calendar.ItemSettings.Size = 15;
				_calendar.ItemSettings.Spacing = 2;
				_calendar.ItemSettings.ShowContinuationArrows = State.Enabled;
				_calendar.ItemSettings.ShowMoreItemsCue = State.Enabled;
				_calendar.ItemSettings.ShowReminderIcons = State.Enabled;

				ShowInfo();

				AddScheduleData();

				PopulateListBox();

				UpdateControls();
			}
			else
			{
				Selection selection = Calendar2.Selection;
				if (!selection.IsEmpty)
				{
					_calendar.TimetableSettings.Dates.Clear();
					DateTime date = selection.Ranges[0];
					DateTime end = selection.Ranges[1];
					while (date < end)
					{
						TimetableDate tDate = new TimetableDate(date);
						_calendar.TimetableSettings.Dates.Add(tDate);
						date += TimeSpan.FromDays(1);
						Session["_dates"] = _calendar.TimetableSettings.Dates;
					}
					selection.Reset();
				}
				else
				{
					TimetableDateCollection temp = (TimetableDateCollection)Session["_dates"];
					if (temp != null)
					{
						_calendar.TimetableSettings.Dates.Clear();
						foreach (var date in temp)
							_calendar.TimetableSettings.Dates.Add((TimetableDate)date);
					}
				}
			}
		}
		
		private void InitSettings()
		{
			_calendar.WeekRangeSettings.ViewStyle = WeekRangeViewStyle.WeekPerRow;
			_calendar.WeekRangeSettings.HeaderStyle = WeekRangeHeaderStyle.Title;
			_calendar.WeekRangeSettings.DayNamesHeaderHeight = Unit.Pixel(16);
			_calendar.WeekRangeSettings.DaySettings.ShowToday = State.Enabled;
			_calendar.WeekRangeSettings.DaySettings.GeneralFormat = "d ";
			_calendar.WeekRangeSettings.DaySettings.FirstDayOfMonthFormat = "d ";
			_calendar.WeekRangeSettings.DaySettings.FirstDayOfYearFormat = "d ";

			_calendar.ListViewSettings.ShowNavigationButtons = State.Enabled;
			_calendar.ListViewSettings.MainHeaderSize = Unit.Pixel(30);
			_calendar.ListViewSettings.CellSettings.ShowToday = State.Enabled;
			_calendar.ListViewSettings.CellSettings.GeneralFormat = "d ";
			_calendar.ListViewSettings.CellSettings.FirstDayOfMonthFormat = "d ";
			_calendar.ListViewSettings.CellSettings.FirstDayOfYearFormat = "d ";

			_calendar.MonthSettings.HeaderStyle = MonthHeaderStyles.Title | MonthHeaderStyles.MonthButtons | MonthHeaderStyles.YearButtons;
			_calendar.MonthSettings.MainHeaderHeight = Unit.Pixel(30);
			_calendar.MonthSettings.DayNamesHeaderHeight = Unit.Pixel(20);
			_calendar.MonthSettings.WeekNumbersHeaderWidth = Unit.Pixel(15);
			_calendar.MonthSettings.DaySettings.ShowToday = State.Enabled;

			_calendar.MonthRangeSettings.HeaderSpacing = 2;
			_calendar.MonthRangeSettings.MonthSpacing = 2;
			_calendar.MonthRangeSettings.HeaderHeight = Unit.Pixel(30);

			_calendar.TimetableSettings.ShowNavigationButtons = State.Enabled;
			_calendar.TimetableSettings.DayHeaderMinSize = Unit.Pixel(16);
			_calendar.TimetableSettings.MainHeaderSize = Unit.Pixel(30);
			_calendar.TimetableSettings.GroupHeaderSize = Unit.Pixel(20);
			_calendar.TimetableSettings.TimelineSize = Unit.Pixel(40);
		}

		/// <summary>
		/// Hides or shows relevant for the current view property controls.
		/// </summary>
		private void ShowInfo()
		{
			switch (_calendar.CurrentView)
			{
				case CalendarView.List:
					infoText.InnerHtml = listInfo;
					pnlSingle.Visible = false;
					pnlMRange.Visible = false;
					pnlTimetable.Visible = false;
					pnlList.Visible = true;
					pnlWeek.Visible = false;
					pnlResource.Visible = false;
					btnGroupBy.Visible = true;
					cblItemSettings.Items[2].Enabled = true;
					is_headerSize.Visible = false;
					lblis_headerSize.Visible = false;
					break;
				case CalendarView.MonthRange:
					infoText.InnerHtml = monthRangeInfo;
					pnlSingle.Visible = true;
					pnlMRange.Visible = true;
					pnlTimetable.Visible = false;
					pnlList.Visible = false;
					pnlWeek.Visible = false;
					pnlResource.Visible = false;
					btnGroupBy.Visible = false;
					cblSinlgeMonth.Items[0].Enabled = false;
					cblSinlgeMonth.Items[1].Enabled = false;
					cblItemSettings.Items[2].Enabled = true;
					is_headerSize.Visible = false;
					lblis_headerSize.Visible = false;
					break;
				case CalendarView.SingleMonth:
					infoText.InnerHtml = singleMonthInfo;
					pnlSingle.Visible = true;
					pnlMRange.Visible = false;
					pnlTimetable.Visible = false;
					pnlList.Visible = false;
					pnlWeek.Visible = false;
					pnlResource.Visible = false;
					btnGroupBy.Visible = false;
					cblSinlgeMonth.Items[0].Enabled = true;
					cblSinlgeMonth.Items[1].Enabled = true;
					cblItemSettings.Items[2].Enabled = true;
					is_headerSize.Visible = false;
					lblis_headerSize.Visible = false;
					break;
				case CalendarView.Timetable:
					infoText.InnerHtml = timetableInfo;
					pnlSingle.Visible = false;
					pnlMRange.Visible = false;
					pnlTimetable.Visible = true;
					pnlList.Visible = false;
					pnlWeek.Visible = false;
					pnlResource.Visible = false;
					btnGroupBy.Visible = true;
					cblItemSettings.Items[2].Enabled = true;
					is_headerSize.Visible = true;
					lblis_headerSize.Visible = true;
					break;
				case CalendarView.WeekRange:
					if (_calendar.WeekRangeSettings.ViewStyle == WeekRangeViewStyle.WeekPerRow || _calendar.WeekRangeSettings.ViewStyle == WeekRangeViewStyle.Unspecified)
					{
						infoText.InnerHtml = weekRangeInfo;
						wr_subHeaderSize.Visible = true;
						cblWeekRange.Items[1].Enabled = true;
						lblwr_subHeaderSize.Visible = true;
						wr_visibleRows.Visible = true;
						lblwr_visibleRows.Visible = true;
					}
					else
					{
						infoText.InnerHtml = singleWeekInfo;
						wr_subHeaderSize.Visible = false;
						cblWeekRange.Items[1].Enabled = false;
						lblwr_subHeaderSize.Visible = false;
						wr_visibleRows.Visible = false;
						lblwr_visibleRows.Visible = false;
					}
					pnlSingle.Visible = false;
					pnlMRange.Visible = false;
					pnlTimetable.Visible = false;
					pnlList.Visible = false;
					pnlWeek.Visible = true;
					pnlResource.Visible = false;
					btnGroupBy.Visible = false;
					cblItemSettings.Items[2].Enabled = true;
					is_headerSize.Visible = false;
					lblis_headerSize.Visible = false;
					break;
				case CalendarView.ResourceView:
					infoText.InnerHtml = resourceInfo;
					pnlSingle.Visible = false;
					pnlMRange.Visible = false;
					pnlTimetable.Visible = false;
					pnlList.Visible = false;
					pnlWeek.Visible = false;
					pnlResource.Visible = true;
					btnGroupBy.Visible = true;
					r_mtunit.Enabled = r_timelines.SelectedIndex > 0;
					r_mtcount.Enabled = r_timelines.SelectedIndex > 0;
					r_mtsize.Enabled = r_timelines.SelectedIndex > 0;
					r_ttunit.Enabled = r_timelines.SelectedIndex > 1;
					r_ttcount.Enabled = r_timelines.SelectedIndex > 1;
					r_ttsize.Enabled = r_timelines.SelectedIndex > 1;
					break;
				default:
					break;
			}
		}

		/// <summary>
		/// Generates predefined Schedule data - appointments, contacts and locations.
		/// </summary>
		private void AddScheduleData()
		{
			TimetableDateCollection dates = _calendar.TimetableSettings.Dates;

			Appointment app = null;
			//Recurrence recurrence = null;
			Reminder reminder = null;
			DateTime date = DateTime.Today;
			TimetableDate theDate = new TimetableDate();
			Random random = new Random(DateTime.Now.Millisecond);

			#region Contacts
			Contact c = null;

			c = new Contact();
			c.FirstName = "Tom";
			c.LastName = "Miles";
			_calendar.Schedule.Contacts.Add(c);

			c = new Contact();
			c.FirstName = "Jimmy";
			c.LastName = "King";
			_calendar.Schedule.Contacts.Add(c);

			c = new Contact();
			c.FirstName = "Elisabeth";
			c.LastName = "Tailor";
			_calendar.Schedule.Contacts.Add(c);
			#endregion

			#region Locations
			Location l1 = null;
			Location l2 = null;

			l1 = new Location();
			l1.Country = "Atlantic Ocean";
			l1.Name = @"25° 0′ 0″ N, 71° 0′ 0″ W";
			_calendar.Schedule.Locations.Add(l1);
			l2 = new Location();
			l2.Country = "USA";
			l2.Name = "Area 51";
			l2.ZipCode = "89044";
			l2.State = "Nevada";
			_calendar.Schedule.Locations.Add(l2);
			#endregion

			#region Create some events

			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 8, 30, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 10, 30, 0);
			app.HeaderText = "Meet George";
			app.DescriptionText = "This is the seventh time I promise George. This time I should go.";
			app.Contacts.Add(_calendar.Schedule.Contacts[random.Next(0, 2)]);
			_calendar.Schedule.Items.Add(app);

			theDate = dates[random.Next() % dates.Count];
			date = theDate.Value;
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 13, 15, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 14, 00, 0);
			app.HeaderText = "Visit the dentist";
			app.DescriptionText = "This reminder is rather pointless, since my tooth is a reminder on its own.";
			app.Location = l1;
			_calendar.Schedule.Items.Add(app);

			// Add a recurring appointment
			theDate = dates[random.Next() % dates.Count];
			date = theDate.Value;
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 12, 00, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 13, 30, 0);
			app.HeaderText = "Lunch with Laura";
			app.Location = l2;
			app.DescriptionText = "Never to forget the appointment with the boss.";

			// The recurrence
			/*recurrence = new Recurrence();
			recurrence.Pattern = RecurrencePattern.Weekly;
			recurrence.DaysOfWeek = DaysOfWeek.Wednesday;
			recurrence.StartDate = date;
			recurrence.RecurrenceEnd = RecurrenceEnd.Never;
			app.Recurrence = recurrence;*/
			_calendar.Schedule.Items.Add(app);

			// Add an appointment with reminder
			theDate = dates[random.Next() % dates.Count];
			date = theDate.Value;
			app = new Appointment();
			app.AllDayEvent = true;
			app.StartTime = date;
			app.EndTime = date + TimeSpan.FromDays(1);
			app.HeaderText = "William's birthday";

			reminder = new Reminder();
			reminder.Message = "It's " + app.HeaderText + " soon!";
			reminder.Type = ReminderType.Leading;
			reminder.TimeInterval = TimeSpan.FromDays(1);
			app.Reminder = reminder;
			app.Contacts.Add(_calendar.Schedule.Contacts[random.Next(0, 2)]);
			_calendar.Schedule.Items.Add(app);

			theDate = dates[random.Next() % dates.Count];
			date = theDate.Value;
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 10, 00, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 16, 00, 0);
			app.HeaderText = "Have fun!";
			app.DescriptionText = "Working hard, but sometimes we need to rest.";
			app.Contacts.Add(_calendar.Schedule.Contacts[random.Next(0, 2)]);
			_calendar.Schedule.Items.Add(app);

			theDate = dates[random.Next() % dates.Count];
			date = theDate.Value;
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 18, 20, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 18, 35, 0);
			app.HeaderText = "Prepare the dinner!";
			app.DescriptionText = "Yeah!";
			_calendar.Schedule.Items.Add(app);

			theDate = dates[random.Next() % dates.Count];
			date = theDate.Value;
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 17, 00, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 17, 45, 0);
			app.HeaderText = "Get the children from the kindergarten!";
			app.DescriptionText = "Yeah!";
			_calendar.Schedule.Items.Add(app);

			theDate = dates[random.Next() % dates.Count];
			date = theDate.Value;
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 17, 30, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 21, 0, 0);
			app.HeaderText = "Arrange the house payments!";
			app.DescriptionText = "Yeah!";
			app.Contacts.Add(_calendar.Schedule.Contacts[random.Next(0, 2)]);
			_calendar.Schedule.Items.Add(app);

			theDate = dates[random.Next() % dates.Count];
			date = theDate.Value;
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 7, 30, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 8, 20, 0);
			app.HeaderText = "Drive kids to school!";
			app.DescriptionText = "Yeah!";
			_calendar.Schedule.Items.Add(app);
			#endregion
		}

		/// <summary>
		/// Updates the contents of the contacts and locations listboxes.
		/// </summary>
		private void PopulateListBox()
		{
			lstContacts.Items.Clear();
			lstLocations.Items.Clear();

			foreach (Contact c in _calendar.Schedule.Contacts)
			{
				bool selected = _calendar.Contacts.Contains(c);
				lstContacts.Items.Add(new ListItem() { Text = c.FirstName + " " + c.LastName, Value = c.Id, Selected = selected });
			}

			foreach (Location l in _calendar.Schedule.Locations)
			{
				bool selected = _calendar.Locations.Contains(l);
				lstLocations.Items.Add(new ListItem() { Text = l.Name, Value = l.Id, Selected = selected });
			}
		}

		/// <summary>
		/// Update values in settings controls on the page.
		/// </summary>
		private void UpdateControls()
		{
			sm_mainHeaderSize.Text = _calendar.MonthSettings.MainHeaderHeight.Value.ToString();
			sm_subHeaderSize.Text = _calendar.MonthSettings.DayNamesHeaderHeight.Value.ToString();
			sm_weekHeaderSize.Text = _calendar.MonthSettings.WeekNumbersHeaderWidth.Value.ToString();
			mr_numberOfMonths.Text = _calendar.MonthRangeSettings.NumberOfMonths.ToString();
			mr_monthsPerRow.Text = _calendar.MonthRangeSettings.MonthsPerRow.ToString();
			mr_VisibleRows.Text = _calendar.MonthRangeSettings.VisibleRows.ToString();
			mr_headerHeight.Text = _calendar.MonthRangeSettings.HeaderHeight.Value.ToString();
			mr_headerSpacing.Text = _calendar.MonthRangeSettings.HeaderSpacing.ToString();
			mr_monthSpacing.Text = _calendar.MonthRangeSettings.MonthSpacing.ToString();
			tt_mainHeaderSize.Text = _calendar.TimetableSettings.MainHeaderSize.Value.ToString();
			tt_subHeaderSize.Text = _calendar.TimetableSettings.GroupHeaderSize.Value.ToString();
			tt_timelineSize.Text = _calendar.TimetableSettings.TimelineSize.Value.ToString();
			tt_cellSize.Text = _calendar.TimetableSettings.CellSize.Value.ToString();
			tt_cellTime.Text = _calendar.TimetableSettings.CellTime.Minutes.ToString();
			lv_headerSize.Text = _calendar.ListViewSettings.MainHeaderSize.Value.ToString();
			lv_numberOfCells.Text = _calendar.ListViewSettings.NumberOfCells.ToString();
			lv_visibleCells.Text = _calendar.ListViewSettings.VisibleCells.ToString();
			lv_dateFormat.Text = _calendar.ListViewSettings.CellSettings.GeneralFormat;
			lv_navButtons.Checked = _calendar.ListViewSettings.ShowNavigationButtons == State.Enabled;
			wr_headerSize.Text = _calendar.WeekRangeSettings.MainHeaderHeight.Value.ToString();
			wr_subHeaderSize.Text = _calendar.WeekRangeSettings.DayNamesHeaderHeight.Value.ToString();
			wr_totalDays.Text = (_calendar.EndDate - _calendar.Date).TotalDays.ToString();
			wr_visibleRows.Text = _calendar.WeekRangeSettings.VisibleRows.ToString();
			r_visibleCells.Text = _calendar.ResourceViewSettings.VisibleCells.ToString();
			r_groupHeaderSize.Text = _calendar.ResourceViewSettings.GroupHeaderSize.Value.ToString();
			r_ttcount.Text = _calendar.ResourceViewSettings.TopTimelineSettings.UnitCount.ToString();
			r_mtcount.Text = _calendar.ResourceViewSettings.MiddleTimelineSettings.UnitCount.ToString();
			r_btcount.Text = _calendar.ResourceViewSettings.BottomTimelineSettings.UnitCount.ToString();
			r_ttsize.Text = _calendar.ResourceViewSettings.TopTimelineSettings.Size.ToString();
			r_mtsize.Text = _calendar.ResourceViewSettings.MiddleTimelineSettings.Size.ToString();
			r_btsize.Text = _calendar.ResourceViewSettings.BottomTimelineSettings.Size.ToString();
			is_size.Text = _calendar.ItemSettings.Size.ToString();
			is_spacing.Text = _calendar.ItemSettings.Spacing.ToString();
			is_headerSize.Text = _calendar.ItemSettings.HeaderSize.Value.ToString();
		}

		/// <summary>
		/// Change calendar's CurrentView.
		/// </summary>
		protected void lstCurrentView_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			if (ddl.SelectedIndex != -1)
			{
				if (ddl.SelectedValue != "SingleWeek")
				{
					_calendar.CurrentView = (CalendarView)Enum.Parse(typeof(CalendarView), ddl.SelectedValue);
					if (ddl.SelectedValue == "WeekRange")
						_calendar.WeekRangeSettings.ViewStyle = WeekRangeViewStyle.WeekPerRow;
				}
				else
				{
					_calendar.CurrentView = CalendarView.WeekRange;
					_calendar.WeekRangeSettings.ViewStyle = WeekRangeViewStyle.SingleWeek;
				}
				
				InitSettings();
				
				UpdateControls();

				ShowInfo();
			}
		}

		/// <summary>
		/// Change calendar's Theme
		/// </summary>
		protected void lstTheme_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			if (ddl.SelectedIndex != -1)
			{
				_calendar.Theme = (ThemeType)Enum.Parse(typeof(ThemeType), ddl.SelectedItem.Text);
				Calendar2.Theme = (ThemeType)Enum.Parse(typeof(ThemeType), ddl.SelectedItem.Text);
			}
		}

		/// <summary>
		/// Clears the calendar's Schedule
		/// </summary>
		protected void btnClear_Click(object sender, EventArgs e)
		{
			_calendar.Schedule.Items.Clear();
			PopulateListBox();
		}

		/// <summary>
		/// Loads calendar's Schedule from file
		/// </summary>
		protected void btnLoad_Click(object sender, EventArgs e)
		{
			string FileName = Server.MapPath(".") + "\\calendar.xml";
			if (!File.Exists(FileName))
				return;
			XmlDocument document = new XmlDocument();
			document.Load(FileName);
			_calendar.Schedule.LoadFromXml(document);
			PopulateListBox();
		}

		/// <summary>
		/// Saves calendar's Schedule to file
		/// </summary>
		protected void btnSave_Click(object sender, EventArgs e)
		{
			string FileName = Server.MapPath(".") + "\\calendar.xml";
			XmlDocument document = new XmlDocument();
			_calendar.Schedule.SaveToXml(document);
			document.Save(FileName);
			PopulateListBox();
		}

		protected void btnAddCon_Click(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(tbConFName.Text + tbConLName.Text))
			{
				Contact c = new Contact()
				{
					FirstName = tbConFName.Text,
					LastName = tbConLName.Text
				};
				_calendar.Schedule.Contacts.Add(c);
				tbConFName.Text = String.Empty;
				tbConLName.Text = String.Empty;
				PopulateListBox();
			}
		}

		protected void btnDelCon_Click(object sender, EventArgs e)
		{
			string id = lstContacts.SelectedValue;
			if (!String.IsNullOrEmpty(id))
			{
				Contact c = _calendar.Schedule.Contacts[id];
				if (c != null)
				{
					_calendar.Schedule.Contacts.Remove(c);
					if (_calendar.Contacts.Contains(c))
						_calendar.Contacts.Remove(c);
					tbConFName.Text = String.Empty;
					tbConLName.Text = String.Empty;
					PopulateListBox();
				}

			}
		}

		protected void btnAddLoc_Click(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(tbLocName.Text))
			{
				Location l = new Location()
				{
					Name = tbLocName.Text
				};
				_calendar.Schedule.Locations.Add(l);
				tbLocName.Text = String.Empty;
				PopulateListBox();
			}
		}

		protected void btnDelLoc_Click(object sender, EventArgs e)
		{
			string id = lstLocations.SelectedValue;
			if (!String.IsNullOrEmpty(id))
			{
				Location l = _calendar.Schedule.Locations[id];
				if (l != null)
				{
					_calendar.Schedule.Locations.Remove(l);
					if (_calendar.Locations.Contains(l))
						_calendar.Locations.Remove(l);
					tbLocName.Text = String.Empty;
					PopulateListBox();
				}

			}
		}

		protected void btnFilterBy_Click(object sender, EventArgs e)
		{
			_calendar.Locations.Clear();
			_calendar.Contacts.Clear();
			if (lstContacts.SelectedIndex != -1)
			{
				// Filter by selected contacts
				for (int i = 0; i < lstContacts.Items.Count; i++)
				{
					var li = lstContacts.Items[i];
					if (li.Selected)
					{
						Contact c = _calendar.Schedule.Contacts[li.Value];
						if (!_calendar.Contacts.Contains(c))
							_calendar.Contacts.Add(c);
					}
				}
				_calendar.GroupType = GroupType.FilterByContacts;
			}
			else if (lstLocations.SelectedIndex != -1)
			{
				// Filter by selected locations
				for (int i = 0; i < lstLocations.Items.Count; i++)
				{
					var li = lstLocations.Items[i];
					if (li.Selected)
					{
						Location l = _calendar.Schedule.Locations[li.Value];
						if (!_calendar.Locations.Contains(l))
							_calendar.Locations.Add(l);
					}
				}
				_calendar.GroupType = GroupType.FilterByLocations;
			}
		}
		protected void btnGroupBy_Click(object sender, EventArgs e)
		{
			_calendar.Locations.Clear();
			_calendar.Contacts.Clear();
			if (lstContacts.SelectedIndex != -1)
			{
				// Group by selected contacts
				for (int i = 0; i < lstContacts.Items.Count; i++)
				{
					var li = lstContacts.Items[i];
					if (li.Selected)
					{
						Contact c = _calendar.Schedule.Contacts[li.Value];
						if (!_calendar.Contacts.Contains(c))
							_calendar.Contacts.Add(c);
					}
				}
				_calendar.GroupType = GroupType.GroupByContacts;
				tt_subHeaderSize.Enabled = true;
				tt_subHeaderSize.ForeColor = Color.Black;
			}
			else if (lstLocations.SelectedIndex != -1)
			{
				// Group by selected locations
				for (int i = 0; i < lstLocations.Items.Count; i++)
				{
					var li = lstLocations.Items[i];
					if (li.Selected)
					{
						Location l = _calendar.Schedule.Locations[li.Value];
						if (!_calendar.Locations.Contains(l))
							_calendar.Locations.Add(l);
					}
				}
				_calendar.GroupType = GroupType.GroupByLocations;
				tt_subHeaderSize.Enabled = true;
				tt_subHeaderSize.ForeColor = Color.Black;
			}
		}
		protected void btnClearGr_Click(object sender, EventArgs e)
		{
			_calendar.Locations.Clear();
			_calendar.Contacts.Clear();
			_calendar.GroupType = GroupType.None;
			tt_subHeaderSize.Enabled = false;
			tt_subHeaderSize.ForeColor = Color.Gray;
		}

		protected void _calendar_VisibleDateChanged(object sender, DateChangedEventArgs e)
		{
			// Ensure the end date is 60 days after the start date
			_calendar.EndDate = e.NewDate + TimeSpan.FromDays(60);
			Session["_dates"] = _calendar.TimetableSettings.Dates;
		}

		#region SingleMonth

		protected void cblSinlgeMonth_SelectedIndexChanged(object sender, EventArgs e)
		{
			if (cblSinlgeMonth.Items[0].Selected)
				_calendar.MonthSettings.HeaderStyle |= MindFusion.Scheduling.WebForms.MonthHeaderStyles.MonthButtons;
			else
				_calendar.MonthSettings.HeaderStyle &= ~MindFusion.Scheduling.WebForms.MonthHeaderStyles.MonthButtons;

			if (cblSinlgeMonth.Items[1].Selected)
				_calendar.MonthSettings.HeaderStyle |= MindFusion.Scheduling.WebForms.MonthHeaderStyles.YearButtons;
			else
				_calendar.MonthSettings.HeaderStyle &= ~MindFusion.Scheduling.WebForms.MonthHeaderStyles.YearButtons;

			if (cblSinlgeMonth.Items[2].Selected)
			{
				_calendar.MonthSettings.DayNamesHeader = MindFusion.Scheduling.WebForms.State.Enabled;
				sm_subHeaderSize.Enabled = true;
				sm_subHeaderSize.ForeColor = Color.Black;
			}
			else
			{
				_calendar.MonthSettings.DayNamesHeader = MindFusion.Scheduling.WebForms.State.Disabled;
				sm_subHeaderSize.Enabled = false;
				sm_subHeaderSize.ForeColor = Color.Gray;
			}

			if (cblSinlgeMonth.Items[3].Selected)
			{
				_calendar.MonthSettings.WeekHeaderStyle = MindFusion.Scheduling.WebForms.MonthWeekHeaderStyle.Left;
				sm_weekHeaderSize.Enabled = true;
				sm_weekHeaderSize.ForeColor = Color.Black;
			}
			else
			{
				_calendar.MonthSettings.WeekHeaderStyle = MindFusion.Scheduling.WebForms.MonthWeekHeaderStyle.None;
				sm_weekHeaderSize.Enabled = false;
				sm_weekHeaderSize.ForeColor = Color.Gray;
			}

			_calendar.MonthSettings.ShowPaddingDays = cblSinlgeMonth.Items[4].Selected ? State.Enabled : State.Disabled;

			_calendar.MonthSettings.ShowPaddingItems = cblSinlgeMonth.Items[5].Selected ? State.Enabled : State.Disabled;

		}

		protected void sm_mainHeaderSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(sm_mainHeaderSize.Text))
			{
				int result;
				if (int.TryParse(sm_mainHeaderSize.Text, out result))
					_calendar.MonthSettings.MainHeaderHeight = new Unit(result, UnitType.Pixel);
				else
					sm_mainHeaderSize.Text = _calendar.MonthSettings.MainHeaderHeight.Value.ToString();
			}
		}

		protected void sm_subHeaderSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(sm_subHeaderSize.Text))
			{
				int result;
				if (int.TryParse(sm_subHeaderSize.Text, out result))
					_calendar.MonthSettings.DayNamesHeaderHeight = new Unit(result, UnitType.Pixel);
				else
					sm_subHeaderSize.Text = _calendar.MonthSettings.DayNamesHeaderHeight.Value.ToString();
			}
		}

		protected void sm_weekHeaderSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(sm_weekHeaderSize.Text))
			{
				int result;
				if (int.TryParse(sm_weekHeaderSize.Text, out result))
					_calendar.MonthSettings.WeekNumbersHeaderWidth = new Unit(result, UnitType.Pixel);
				else
					sm_weekHeaderSize.Text = _calendar.MonthSettings.WeekNumbersHeaderWidth.Value.ToString();
			}
		}

		#endregion

		#region MonthRange

		protected void mr_numberOfMonths_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(mr_numberOfMonths.Text))
			{
				int result;
				if (int.TryParse(mr_numberOfMonths.Text, out result))
					_calendar.MonthRangeSettings.NumberOfMonths = result;
				else
					mr_numberOfMonths.Text = _calendar.MonthRangeSettings.NumberOfMonths.ToString();
			}
		}

		protected void mr_monthsPerRow_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(mr_monthsPerRow.Text))
			{
				int result;
				if (int.TryParse(mr_monthsPerRow.Text, out result))
					_calendar.MonthRangeSettings.MonthsPerRow = result;
				else
					mr_monthsPerRow.Text = _calendar.MonthRangeSettings.MonthsPerRow.ToString();
			}
		}

		protected void mr_VisibleRows_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(mr_VisibleRows.Text))
			{
				int result;
				if (int.TryParse(mr_VisibleRows.Text, out result))
					_calendar.MonthRangeSettings.VisibleRows = result;
				else
					mr_VisibleRows.Text = _calendar.MonthRangeSettings.VisibleRows.ToString();
			}
		}

		protected void mr_headerHeight_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(mr_headerHeight.Text))
			{
				int result;
				if (int.TryParse(mr_headerHeight.Text, out result))
					_calendar.MonthRangeSettings.HeaderHeight = new Unit(result, UnitType.Pixel);
				else
					mr_headerHeight.Text = _calendar.MonthRangeSettings.HeaderHeight.Value.ToString();
			}
		}
		protected void mr_headerSpacing_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(mr_headerSpacing.Text))
			{
				int result;
				if (int.TryParse(mr_headerSpacing.Text, out result))
					_calendar.MonthRangeSettings.HeaderSpacing = result;
				else
					mr_headerSpacing.Text = _calendar.MonthRangeSettings.HeaderSpacing.ToString();
			}
		}

		protected void mr_monthSpacing_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(mr_monthSpacing.Text))
			{
				int result;
				if (int.TryParse(mr_monthSpacing.Text, out result))
					_calendar.MonthRangeSettings.MonthSpacing = result;
				else
					mr_monthSpacing.Text = _calendar.MonthRangeSettings.MonthSpacing.ToString();
			}
		}

		protected void mr_navButtons_CheckedChanged(object sender, EventArgs e)
		{
			if (mr_navButtons.Checked)
				_calendar.MonthRangeSettings.HeaderStyle |= MonthRangeHeaderStyles.Buttons;
			else
				_calendar.MonthRangeSettings.HeaderStyle &= ~MonthRangeHeaderStyles.Buttons;
		}

		#endregion

		#region Timetable

		protected void ddlTimetableOrientation_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			switch (ddl.SelectedIndex)
			{
				case 0:
					_calendar.TimetableSettings.Orientation = MindFusion.Scheduling.WebForms.Orientation.Horizontal;
					break;
				case 1:
					_calendar.TimetableSettings.Orientation = MindFusion.Scheduling.WebForms.Orientation.Vertical;
					break;
				default:
					break;
			}
		}

		protected void cblTimetable_SelectedIndexChanged(object sender, EventArgs e)
		{
			_calendar.TimetableSettings.ShowNavigationButtons =
				cblTimetable.Items[0].Selected ? State.Enabled : State.Disabled;
			_calendar.TimetableSettings.ShowDayHeader =
				cblTimetable.Items[1].Selected ? State.Enabled : State.Disabled;
			_calendar.TimetableSettings.ShowExpandButton =
				cblTimetable.Items[2].Selected ? State.Enabled : State.Disabled;
		}

		protected void tt_mainHeaderSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(tt_mainHeaderSize.Text))
			{
				int result;
				if (int.TryParse(tt_mainHeaderSize.Text, out result))
					_calendar.TimetableSettings.MainHeaderSize = new Unit(result, UnitType.Pixel);
				else
					tt_mainHeaderSize.Text = _calendar.TimetableSettings.MainHeaderSize.Value.ToString();
			}
		}

		protected void tt_subHeaderSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(tt_subHeaderSize.Text))
			{
				int result;
				if (int.TryParse(tt_subHeaderSize.Text, out result))
					_calendar.TimetableSettings.GroupHeaderSize = new Unit(result, UnitType.Pixel);
				else
					tt_subHeaderSize.Text = _calendar.TimetableSettings.GroupHeaderSize.Value.ToString();
			}
		}

		protected void tt_timelineSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(tt_timelineSize.Text))
			{
				int result;
				if (int.TryParse(tt_timelineSize.Text, out result))
					_calendar.TimetableSettings.TimelineSize = new Unit(result, UnitType.Pixel);
				else
					tt_timelineSize.Text = _calendar.TimetableSettings.TimelineSize.Value.ToString();
			}
		}

		protected void tt_cellSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(tt_cellSize.Text))
			{
				int result;
				if (int.TryParse(tt_cellSize.Text, out result))
					_calendar.TimetableSettings.CellSize = new Unit(result, UnitType.Pixel);
				else
					tt_cellSize.Text = _calendar.TimetableSettings.CellSize.Value.ToString();
			}
		}

		protected void tt_cellTime_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(tt_cellTime.Text))
			{
				int result;
				if (int.TryParse(tt_cellTime.Text, out result))
				{
					if (result > 0 && result <= 60)
						_calendar.TimetableSettings.CellTime = TimeSpan.FromMinutes(result);
					tt_cellTime.Text = _calendar.TimetableSettings.CellTime.Minutes.ToString();
				}
				else
					tt_cellTime.Text = _calendar.TimetableSettings.CellTime.Minutes.ToString();
			}
		}

		#endregion

		#region List

		protected void ddlListView_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			switch (ddl.SelectedIndex)
			{
				case 0:
					_calendar.ListViewSettings.CellUnits = TimeUnit.Second;
					_calendar.ListViewSettings.TitleFormat = "dd MMM ddd,<br />hh:mm:ss";
					break;
				case 1:
					_calendar.ListViewSettings.CellUnits = TimeUnit.Minute;
					_calendar.ListViewSettings.TitleFormat = "dd MMM ddd,<br />hh:mm";
					break;
				case 2:
					_calendar.ListViewSettings.CellUnits = TimeUnit.Hour;
					_calendar.ListViewSettings.TitleFormat = "dd MMM ddd,<br />hh:mm";
					break;
				case 3:
					_calendar.ListViewSettings.CellUnits = TimeUnit.Day;
					_calendar.ListViewSettings.TitleFormat = "ddd,<br />dd MMM";
					break;
				case 4:
					_calendar.ListViewSettings.CellUnits = TimeUnit.Week;
					_calendar.ListViewSettings.TitleFormat = "ddd,<br />dd MMM";
					break;
				case 5:
					_calendar.ListViewSettings.CellUnits = TimeUnit.Month;
					_calendar.ListViewSettings.TitleFormat = "ddd,<br />dd MMM yyyy";
					break;
				case 6:
					_calendar.ListViewSettings.CellUnits = TimeUnit.Year;
					_calendar.ListViewSettings.TitleFormat = "ddd,<br />dd MMM yyyy";
					break;
				default:
					break;
			}
		}

		protected void ddlListViewOrientation_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			switch (ddl.SelectedIndex)
			{
				case 0:
					_calendar.ListViewSettings.Orientation = MindFusion.Scheduling.WebForms.Orientation.Horizontal;
					break;
				case 1:
					_calendar.ListViewSettings.Orientation = MindFusion.Scheduling.WebForms.Orientation.Vertical;
					break;
				default:
					break;
			}
		}
		protected void lv_headerSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(lv_headerSize.Text))
			{
				int result;
				if (int.TryParse(lv_headerSize.Text, out result))
					_calendar.ListViewSettings.MainHeaderSize = new Unit(result, UnitType.Pixel);
				else
					lv_headerSize.Text = _calendar.ListViewSettings.MainHeaderSize.Value.ToString();
			}
		}

		protected void lv_numberOfCells_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(lv_numberOfCells.Text))
			{
				int result;
				if (int.TryParse(lv_numberOfCells.Text, out result))
					_calendar.ListViewSettings.NumberOfCells = result;
				else
					lv_numberOfCells.Text = _calendar.ListViewSettings.NumberOfCells.ToString();
			}
		}

		protected void lv_visibleCells_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(lv_visibleCells.Text))
			{
				int result;
				if (int.TryParse(lv_visibleCells.Text, out result))
					_calendar.ListViewSettings.VisibleCells = result;
				else
					lv_visibleCells.Text = _calendar.ListViewSettings.VisibleCells.ToString();
			}
		}

		protected void lv_navButtons_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.ListViewSettings.ShowNavigationButtons = lv_navButtons.Checked ? State.Enabled : State.Disabled;
		}

		protected void lv_dateFormat_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(lv_dateFormat.Text))
			{
				string format = lv_dateFormat.Text;
				_calendar.ListViewSettings.CellSettings.GeneralFormat = format;
				_calendar.ListViewSettings.CellSettings.FirstDayOfMonthFormat = format;
				_calendar.ListViewSettings.CellSettings.FirstDayOfYearFormat = format;
			}
		}

		#endregion

		#region WeekRange

		protected void cblWeekRange_SelectedIndexChanged(object sender, EventArgs e)
		{
			bool showMainHeader = cblWeekRange.Items[0].Selected;
			_calendar.WeekRangeSettings.HeaderStyle = showMainHeader ? WeekRangeHeaderStyle.Title : WeekRangeHeaderStyle.None;
			wr_headerSize.Enabled = showMainHeader;
			wr_headerSize.ForeColor = showMainHeader ? Color.Black : Color.Gray;

			bool showSubHeader = cblWeekRange.Items[1].Selected;
			_calendar.WeekRangeSettings.DayNamesHeader = showSubHeader ? State.Enabled : State.Disabled;
			wr_subHeaderSize.Enabled = showSubHeader;
			wr_subHeaderSize.ForeColor = showSubHeader ? Color.Black : Color.Gray;
		}

		protected void wr_headerSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(wr_headerSize.Text))
			{
				int result;
				if (int.TryParse(wr_headerSize.Text, out result))
					_calendar.WeekRangeSettings.MainHeaderHeight = new Unit(result, UnitType.Pixel);
				else
					wr_headerSize.Text = _calendar.WeekRangeSettings.MainHeaderHeight.Value.ToString();
			}
		}
		protected void wr_subHeaderSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(wr_subHeaderSize.Text))
			{
				int result;
				if (int.TryParse(wr_subHeaderSize.Text, out result))
					_calendar.WeekRangeSettings.DayNamesHeaderHeight = new Unit(result, UnitType.Pixel);
				else
					wr_subHeaderSize.Text = _calendar.WeekRangeSettings.DayNamesHeaderHeight.Value.ToString();
			}
		}
		protected void wr_totalDays_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(wr_totalDays.Text))
			{
				int result;
				if (int.TryParse(wr_totalDays.Text, out result))
					_calendar.EndDate = _calendar.Date.AddDays(result);
				else
					wr_totalDays.Text = (_calendar.EndDate - _calendar.Date).TotalDays.ToString();
			}
		}

		protected void wr_visibleRows_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(wr_visibleRows.Text))
			{
				int result;
				if (int.TryParse(wr_visibleRows.Text, out result))
					_calendar.WeekRangeSettings.VisibleRows = result;
				else
					wr_visibleRows.Text = _calendar.WeekRangeSettings.VisibleRows.ToString();
			}
		}

		#endregion

		#region ResourceView
		protected void r_timelines_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			_calendar.ResourceViewSettings.Timelines = (ddl.SelectedIndex + 1);
			r_mtunit.Enabled = r_timelines.SelectedIndex > 0;
			r_mtcount.Enabled = r_timelines.SelectedIndex > 0;
			r_mtsize.Enabled = r_timelines.SelectedIndex > 0;
			r_ttunit.Enabled = r_timelines.SelectedIndex > 1;
			r_ttcount.Enabled = r_timelines.SelectedIndex > 1;
			r_ttsize.Enabled = r_timelines.SelectedIndex > 1;
		}

		protected void r_visibleCells_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(r_visibleCells.Text))
			{
				int result;
				if (int.TryParse(r_visibleCells.Text, out result))
					_calendar.ResourceViewSettings.VisibleCells = result;
				else
					r_visibleCells.Text = _calendar.ResourceViewSettings.VisibleCells.ToString();
			}
		}

		protected void r_groupHeaderSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(r_groupHeaderSize.Text))
			{
				int result;
				if (int.TryParse(r_groupHeaderSize.Text, out result))
					_calendar.ResourceViewSettings.GroupHeaderSize = new Unit(result, UnitType.Pixel);
				else
					r_groupHeaderSize.Text = _calendar.ResourceViewSettings.GroupHeaderSize.Value.ToString();
			}
		}

		protected void r_ttunit_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			switch (ddl.SelectedIndex)
			{
				case 0:
					_calendar.ResourceViewSettings.TopTimelineSettings.Unit = TimeUnit.Hour;
					_calendar.ResourceViewSettings.TopTimelineSettings.Format = "dd MMM ddd,<br />hh:mm";
					break;
				case 1:
					_calendar.ResourceViewSettings.TopTimelineSettings.Unit = TimeUnit.Day;
					_calendar.ResourceViewSettings.TopTimelineSettings.Format = "ddd,<br />dd MMM";
					break;
				case 2:
					_calendar.ResourceViewSettings.TopTimelineSettings.Unit = TimeUnit.Week;
					_calendar.ResourceViewSettings.TopTimelineSettings.Format = "ddd,<br />dd MMM";
					break;
				case 3:
					_calendar.ResourceViewSettings.TopTimelineSettings.Unit = TimeUnit.Month;
					_calendar.ResourceViewSettings.TopTimelineSettings.Format = "ddd,<br />dd MMM yyyy";
					break;
				case 4:
					_calendar.ResourceViewSettings.TopTimelineSettings.Unit = TimeUnit.Year;
					_calendar.ResourceViewSettings.TopTimelineSettings.Format = "ddd,<br />dd MMM yyyy";
					break;
				default:
					break;
			}
		}

		protected void r_mtunit_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			switch (ddl.SelectedIndex)
			{
				case 0:
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Unit = TimeUnit.Hour;
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Format = "dd MMM ddd,<br />hh:mm";
					break;
				case 1:
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Unit = TimeUnit.Day;
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Format = "ddd,<br />dd MMM";
					break;
				case 2:
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Unit = TimeUnit.Week;
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Format = "ddd,<br />dd MMM";
					break;
				case 3:
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Unit = TimeUnit.Month;
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Format = "ddd,<br />dd MMM yyyy";
					break;
				case 4:
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Unit = TimeUnit.Year;
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Format = "ddd,<br />dd MMM yyyy";
					break;
				default:
					break;
			}
		}

		protected void r_btunit_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			switch (ddl.SelectedIndex)
			{
				case 0:
					_calendar.ResourceViewSettings.BottomTimelineSettings.Unit = TimeUnit.Hour;
					_calendar.ResourceViewSettings.BottomTimelineSettings.Format = "dd MMM ddd,<br />hh:mm";
					break;
				case 1:
					_calendar.ResourceViewSettings.BottomTimelineSettings.Unit = TimeUnit.Day;
					_calendar.ResourceViewSettings.BottomTimelineSettings.Format = "ddd,<br />dd MMM";
					break;
				case 2:
					_calendar.ResourceViewSettings.BottomTimelineSettings.Unit = TimeUnit.Week;
					_calendar.ResourceViewSettings.BottomTimelineSettings.Format = "ddd,<br />dd MMM";
					break;
				case 3:
					_calendar.ResourceViewSettings.BottomTimelineSettings.Unit = TimeUnit.Month;
					_calendar.ResourceViewSettings.BottomTimelineSettings.Format = "ddd,<br />dd MMM yyyy";
					break;
				case 4:
					_calendar.ResourceViewSettings.BottomTimelineSettings.Unit = TimeUnit.Year;
					_calendar.ResourceViewSettings.BottomTimelineSettings.Format = "ddd,<br />dd MMM yyyy";
					break;
				default:
					break;
			}
		}

		protected void r_ttcount_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(r_ttcount.Text))
			{
				int result;
				if (int.TryParse(r_ttcount.Text, out result))
					_calendar.ResourceViewSettings.TopTimelineSettings.UnitCount = result;
				else
					r_ttcount.Text = _calendar.ResourceViewSettings.TopTimelineSettings.UnitCount.ToString();
			}
		}

		protected void r_mtcount_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(r_mtcount.Text))
			{
				int result;
				if (int.TryParse(r_mtcount.Text, out result))
					_calendar.ResourceViewSettings.MiddleTimelineSettings.UnitCount = result;
				else
					r_mtcount.Text = _calendar.ResourceViewSettings.MiddleTimelineSettings.UnitCount.ToString();
			}
		}

		protected void r_btcount_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(r_btcount.Text))
			{
				int result;
				if (int.TryParse(r_btcount.Text, out result))
					_calendar.ResourceViewSettings.BottomTimelineSettings.UnitCount = result;
				else
					r_btcount.Text = _calendar.ResourceViewSettings.BottomTimelineSettings.UnitCount.ToString();
			}
		}

		protected void r_ttsize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(r_ttsize.Text))
			{
				int result;
				if (int.TryParse(r_ttsize.Text, out result))
					_calendar.ResourceViewSettings.TopTimelineSettings.Size = result;
				else
					r_ttsize.Text = _calendar.ResourceViewSettings.TopTimelineSettings.Size.ToString();
			}
		}

		protected void r_mtsize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(r_mtsize.Text))
			{
				int result;
				if (int.TryParse(r_mtsize.Text, out result))
					_calendar.ResourceViewSettings.MiddleTimelineSettings.Size = result;
				else
					r_mtsize.Text = _calendar.ResourceViewSettings.MiddleTimelineSettings.Size.ToString();
			}
		}

		protected void r_btsize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(r_btsize.Text))
			{
				int result;
				if (int.TryParse(r_btsize.Text, out result))
					_calendar.ResourceViewSettings.BottomTimelineSettings.Size = result;
				else
					r_btsize.Text = _calendar.ResourceViewSettings.BottomTimelineSettings.Size.ToString();
			}
		}
		#endregion

		#region ItemSettings

		protected void cblItemSettings_SelectedIndexChanged(object sender, EventArgs e)
		{
			_calendar.ItemSettings.ItemsVisible =
				cblItemSettings.Items[0].Selected ? State.Enabled : State.Disabled;
			_calendar.ItemSettings.ShowContinuationArrows =
				cblItemSettings.Items[1].Selected ? State.Enabled : State.Disabled;
			_calendar.ItemSettings.ShowMoreItemsCue =
				cblItemSettings.Items[2].Selected ? State.Enabled : State.Disabled;
			_calendar.ItemSettings.ShowReminderIcons =
				cblItemSettings.Items[3].Selected ? State.Enabled : State.Disabled;
		}

		protected void is_size_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(is_size.Text))
			{
				int result;
				if (int.TryParse(is_size.Text, out result))
					_calendar.ItemSettings.Size = result;
				else
					is_size.Text = _calendar.ItemSettings.Size.ToString();
			}
		}

		protected void is_spacing_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(is_spacing.Text))
			{
				int result;
				if (int.TryParse(is_spacing.Text, out result))
					_calendar.ItemSettings.Spacing = result;
				else
					is_spacing.Text = _calendar.ItemSettings.Spacing.ToString();
			}
		}

		protected void is_headerSize_Changed(object sender, EventArgs e)
		{
			if (!String.IsNullOrEmpty(is_headerSize.Text))
			{
				int result;
				if (int.TryParse(is_headerSize.Text, out result))
					_calendar.ItemSettings.HeaderSize = new Unit(result, UnitType.Pixel);
				else
					is_headerSize.Text = _calendar.ItemSettings.HeaderSize.Value.ToString();
			}
		}

		protected void is_class_SelectedIndexChanged(object sender, EventArgs e)
		{
			_calendar.ItemSettings.CssClass = is_class.Items[is_class.SelectedIndex].Text;
		}

		#endregion

		private static readonly string singleMonthInfo = @"This section contains information and samples about the SingleMonth view. That view displays a single month of the year at a time. The view can optionally display a header showing the month and year name, a header that shows the days of the week and a header that displays the week numbers. You can experiment with the controls at the bottom of the page to see how different aspects of the view can be modified.";
		private static readonly string monthRangeInfo = @"Here you can see the MonthRange view, which is used to display several consecutive months at once. The view usually contains a header and optionally displays navigation buttons. Use the controls at the bottom of the window to change various appearance settings of this view.";
		private static readonly string weekRangeInfo = @"Here you can see the WeekRange view. As its name suggests, this view is used to display a sequence of weeks arranged in 7-day rows. The number of days that can be contained in the view at once is unlimited. This view is very similar to the Calendar view in MS Outlook. As in the other steps, you can adjust some properties of this view using the controls at the bottom of the page. The WeekRange view supports two layouts for presenting dates - the single week layout and the multiple week layout. In the multiple week layout there are several weeks visible at the same time, each one displayed in its own row.";
		private static readonly string singleWeekInfo = @"Here you can see the WeekRange view. As its name suggests, this view is used to display a sequence of weeks arranged in 7-day rows. The number of days that can be contained in the view at once is unlimited. This view is very similar to the Calendar view in MS Outlook. As in the other steps, you can adjust some properties of this view using the controls at the bottom of the page. The WeekRange view supports two layouts for presenting dates - the single week layout and the multiple week layout. In the single week layout, there is only one week shown at a time. The days of the displayed week are arranged in 2 columns and 3 rows.";
		private static readonly string timetableInfo = @"This step illustrates the Timetable view. This view displays one or more days, divided in arbitrary time intervals from 1 to 60 minutes. The view can display a timeline on the left, and a header containing the date of each day at the top. Experiment with the controls at the bottom of the page to see how various elements of the view can be customized.";
		private static readonly string listInfo = @"This is the List view. The List view is used to display an arbitrary long sequence of seconds, minutes, hours, days, weeks, months or years. The view provides a header displaying the date of the corresponding cell, formatted according to the calendar culture and a customizable formatting string. Use the controls at the bottom of the page to change some appearance options of this view.";
		private static readonly string resourceInfo = @"This is the Resource view. This view displays the distribution of items over a period of time for particular contacts, locations, tasks or resources. The view displays a single row for each individual contact, location, task or resource and up to three timelines. In order to view associated items in this view, the GroupType property of the Calendar must be set to GroupByContacts, GroupByLocations, GroupByTasks or GroupByResources.";
	}
}
